#! /bin/sh

#
# This script install sc68 resource files in the $HOME/.sc68 directory. 
#
# This file is part sc68 1.2.0.
# It is distribued under GNU GPL version 2 or later.
#
# Copyright (C) Ben(jamin) Gerard
#
# $Id: sc68-install.sh.in,v 1.2 2001/12/24 22:54:21 ben Exp $
#

# configure path
# --------------
prefix="/usr"
exec_prefix="/usr"
data_dir="/usr/share"
version="1.2.0"
include_dir="/usr/include"
lib_dir="/usr/lib"
tar=gtar

# sc68 user resource path
# -----------------------
RSC68="${data_dir}/sc68-resources-${version}.tar.gz"
CFG68="$HOME/.sc68/Config/config.txt"
BAK68="$HOME/.sc68/Config/config-bak-${version}.txt"
ORG68="$HOME/.sc68/Config/config-org-${version}.txt"
BACKUP=no
FORCE=

# Check command line parameters
# -----------------------------
if test $# -ge 2; then 
    echo "Too many parameters. Try --help."
    exit 1
fi

if test $# -eq 1; then
    case "$1" in
	--help)
	    echo "sc68-install.sh [--help | --force]"
	    exit 1
	    ;;
	--force)
	    FORCE="f"
	    ;;
	*)
	    echo "Invalid parameter. Try --help."
	    exit 2
	    ;;
    esac
fi

# Check for sc68 resource tarball
# -------------------------------
if test -e "${RSC68}"; then
    "${tar}" tzf "${RSC68}" > /dev/null
    if test $? -ne 0; then
	echo "Not a valid sc68 resource tarball."
	exit 8
    fi
else
    echo "Can *NOT* find sc68 resource tarball at this location:"
    echo "${RSC68}"
    echo "sc68 has *NOT* been installed correctly."
    exit 7
fi

# Go to the HOME directory
# ------------------------
cd "$HOME"

# Check for previous config file
# ------------------------------
if test -d .sc68; then
    if test -e "$CFG68"; then
	echo "A previous version of sc68 file already exist."
	echo "Make a backup of the configuration file:"
	cp "-v${FORCE}" "$CFG68" "$BAK68" && BACKUP=yes
	if test $? -ne 0; then
	    echo "Can *NOT* backup config file."
	    echo "Try --force or check permissons."
	    exit 3
	fi
    fi
elif test -e .sc68; then
    # File exist and is not a directory.
    # ----------------------------------
    echo "A file .sc68 already exist in your HOME directory which is not a directory:"
    echo "$HOME/.sc68"
    echo "I can *NOT* tell if this file is important or not."
    echo "Probably not. You may try to rename it."
    exit 4
else
    # Create directory
    # ----------------
    mkdir .sc68 || exit 5
fi

cd .sc68 || exit 9
"${tar}" xzf "${RSC68}"
if test $? -ne 0; then
    echo "Problem while installing sc68 resource."
    echo "Check permissions in this directory: $HOME/.sc68"
    exit 10
fi
echo "sc68 resource files installed successfully."

if test ! -w "${CFG68}"; then
  chmod u+w "${CFG68}"
fi

# Restore old config file, and save new config
# --------------------------------------------
if test ${BACKUP} = "yes"; then
    echo "Backup  new sc68 config file and restore your old one."

    cp "-v${FORCE}" "${CFG68}" "${ORG68}"
    cp "-v${FORCE}" "${BAK68}" "${CFG68}"
fi
